import $ from 'jquery';
require('selectize.js/dist/js/selectize');

require('./ep-tecdoc.scss');

$(function() {
    let $form = $('#tecdoc-woo-form'),
        $selected = $('.selected-vehicle'),

        $manufacturers = $('#tecdoc-woo-manufacturer'),
        $models = $('#tecdoc-woo-model'),
        $vehicles = $('#tecdoc-woo-type'),
        $shopButton = $('#tecdoc-submit');

    function ajaxRequest(action, callback, params) {
        params = params || {};
        params.action = action;

        $.ajax({
            url: tecdoc_settings_object.ajax_url,
            data: params,
            method: 'POST',
            success: callback
        });
    }

    function getCookie(name) {
        var cookies = {};

        document.cookie.split(';').forEach(function (item) {
            item = item.split('=');
            cookies[item[0].replace(/^\s+|\s+$/, '')] = item[1];
        });

        if (typeof cookies[name] !== 'undefined') {
            return cookies[name];
        }

        return null;
    }

    function setCookie(name, value) {
        var date = new Date(new Date().setFullYear(new Date().getFullYear() + 1));
        document.cookie = name + '=' + value + ';path=/;expires=' + date.toUTCString();
    }

    function clearCookie(name) {
        document.cookie = name + '=;path=/;expires=Thu, 01 Jan 1970 00:00:00 GMT';
    }

    function startLoad($elem) {
        var $holder = $elem.closest('.holder'),
            $loader = $holder.find('.loader');

        hideElem($elem);
        $loader.removeClass('hidden');
    }

    function hideElem($elem) {
        $elem.closest('.col-inner').addClass('hidden');
    }

    function stopLoad($elem) {
        var $holder = $elem.closest('.holder'),
            $loader = $holder.find('.loader');

        $loader.addClass('hidden');
        showElem($elem);
    }

    function showElem($elem) {
        $elem.closest('.col-inner').removeClass('hidden');
    }

    function initManufacturers() {
        $manufacturers.selectize({
            optgroupField: 'group',
            optgroups: [
                {value: 'featured', label: tecdoc_settings_object.strings.featuredManufacturers, label_sele: ''},
                {value: 'rest', label: tecdoc_settings_object.strings.allManufacturers, label_sele: ''}
            ],
            valueField: 'id',
            labelField: 'name',
            render: {
                optgroup_header: function (data, escape) {
                    return '<div class="optgroup-header">' + escape(data.label) + '</div>';
                }
            },
            maxItems: 1,
            searchField: 'name',
            lockOptgroupOrder: true,
            create: false,
            preload: true
        });

        loadManufacturers();
    }

    function loadManufacturers() {
        $manufacturers.off('change');

        ajaxRequest('tecdoc_get_manufacturers', function (data) {
            var selectize = $manufacturers[0].selectize,
                selected = parseInt(getCookie('manufacturerId'));

            selectize.addOption(data);
            stopLoad($manufacturers);

            if (selected) {
                selectize.setValue(selected);
            } else {
                selectize.focus();
            }

            $manufacturers.on('change', function () {
                loadModels(this.value);
            });
        });
    }

    function initModels() {
        $models.selectize({
            optgroupField: 'group',
            optgroups: [
                {value: 'default', label: '', label_sele: ''}
            ],
            valueField: 'id',
            labelField: 'name',
            render: {
                optgroup_header: function () {
                    return '<div class="model thead">' +
                        '<div class="name">' + tecdoc_settings_object.strings.model + '</div>' +
                        '<div class="year">' + tecdoc_settings_object.strings.year + '</div>' +
                        '</div>';
                },
                item: function (item, escape) {
                    return '<div class="model tbody">' +
                        '<div class="name">' + escape(item.name) + '</div>' +
                        '</div>';
                },
                option: function (item, escape) {
                    return '<div class="model">' +
                        '<div class="name">' + escape(item.name) + '</div>' +
                        '<div class="year">' + escape(item.year) + '</div>' +
                        '</div>';
                }
            },
            searchField: 'name'
        });
    }

    function loadModels(manufacturerId) {
        $models.off('change');

        var selectize = $models[0].selectize,
            selected = parseInt(getCookie('modelId'));

        selectize.disable();
        selectize.clearOptions();
        startLoad($models);

        if (manufacturerId) {
            ajaxRequest('tecdoc_get_models', function (data) {
                selectize.addOption(data);
                selectize.enable();
                stopLoad($models);

                if (selected) {
                    selectize.setValue(selected);
                } else {
                    selectize.focus();
                }

                $models.on('change', function () {
                    loadVehicles(parseInt($manufacturers.val()), this.value);
                });
            }, {
                manufacturerId: parseInt(manufacturerId)
            });
        }
    }

    function initVehicles() {
        $vehicles.selectize({
            optgroupField: 'group',
            optgroups: [
                {value: 'default', label: '', label_sele: ''}
            ],
            valueField: 'slug',
            labelField: 'name',
            searchField: 'name',
            render: {
                optgroup_header: function () {
                    return '<div class="model thead">' +
                        '<div class="type">' + tecdoc_settings_object.strings.type + '</div>' +
                        '<div class="motor_type">' + tecdoc_settings_object.strings.motorType + '</div>' +
                        '<div class="power">' + tecdoc_settings_object.strings.power + '</div>' +
                        '</div>';
                },
                item: function (item, escape) {
                    return '<div>' + escape(item.name) + ' - ' + escape(item.engine) + ' ' + escape(item.power) + '</div>';
                },
                option: function (item, escape) {
                    return '<div class="model">' +
                        '<div class="type">' + escape(item.name) + '</div>' +
                        '<div class="motor_type">' + escape(item.engine) + '</div>' +
                        '<div class="power">' + escape(item.power) + '</div>' +
                        '</div>';
                }
            }
        });
    }

    function loadVehicles(manufacturerId, modelId) {
        $vehicles.off('change');

        var selectize = $vehicles[0].selectize,
            selected = parseInt(getCookie('vehicleId'));

        selectize.disable();
        selectize.clearOptions();
        startLoad($vehicles);

        if (manufacturerId && modelId) {
            ajaxRequest('tecdoc_get_vehicles', function (data) {
                selectize.addOption(data);
                selectize.enable();
                stopLoad($vehicles);

                if (selected) {
                    selectize.setValue(selected);
                    $shopButton.removeClass('disabled');
                } else {
                    selectize.focus();
                }

                $vehicles.on('change', function () {
                    if (this.value) {
                        setCookie('_tecdoc', this.value);
                        $shopButton.removeClass('disabled');
                        goShop();
                    } else {
                        clearCookie('_tecdoc');
                        $shopButton.addClass('disabled');
                    }
                });
            }, {
                manufacturerId: manufacturerId,
                modelId: modelId
            });
        }
    }

    function goShop() {
        $shopButton.find('.loader-wrapper, .loader').removeClass('hidden');
        $shopButton.addClass('disabled');
        setTimeout(function () {
            document.location.href = $shopButton.attr('href');
        }, 0);
    }

    $(document).on('click', '.shop-link', function (e) {
        e.preventDefault();
        var $link = $(this);
        $link.find('.loader-wrapper, .loader').removeClass('hidden');
        setTimeout(function () {
            document.location.href = $link.attr('href');
        }, 0);
    });

    function displayVehicle() {
        $form.addClass('hidden');
        $selected.removeClass('hidden');

        ajaxRequest('tecdoc_vehicle', function (data) {
            if (data !== '0') {
                $selected.find('.selected-vehicle-display').html(data);

                if ($selected.find('img').length > 0) {
                    $selected.addClass('has-image');
                } else {
                    $selected.removeClass('has-image');
                }

                $selected.find('.selected-vehicle-change').on('click', function () {
                    clearCookie('_tecdoc');
                    initForm();

                    $selected.addClass('hidden');
                    $form.removeClass('hidden');
                    $manufacturers[0].selectize.focus();
                });
            } else {
                clearCookie('_tecdoc');
                initForm();
            }
        });
    }

    function initForm() {
        initManufacturers();
        initModels();
        initVehicles();
        $selected.addClass('hidden');
        $form.removeClass('hidden');
        $form.css('opacity', 1);
    }

    if (getCookie('_tecdoc')) {
        displayVehicle();
    } else {
        initForm();
    }
});