<?php

if (! defined('ABSPATH')) {
	exit;
}

/**
 * WooCommerce overrides class
 */
class wooCommerceOverrides
{
	/**
	 * Chosen manufacturer TecDoc ID
	 */
	protected $manuId;

	/**
	 * Chosen manufacturer TecDoc ID
	 */
	protected $modelId;

	/**
	 * Chosen manufacturer TecDoc ID
	 */
	protected $typeId;

	/**
	 * Single product information
	 */
	protected $product_info;

	/**
	 * WooCommerce permalink structure
	 */
	protected $permalink_structure;


	public function __construct()
	{
		// Register session
		add_action('init', array($this, 'init_actions'));
			// Show empty categories
		add_filter('woocommerce_product_subcategories_hide_empty', array($this, 'hide_empty_categories'), 10, 1);
		// Remove product count from category list below category name
		add_filter('woocommerce_subcategory_count_html', array($this, 'hide_category_count'));
		// Override Woo breadcrumb search results
		add_filter('woocommerce_get_breadcrumb', array($this, 'filter_woocommerce_get_breadcrumb'), 10, 2);
		// Add TecDoc tab to product single
		add_filter('woocommerce_product_tabs', array($this, 'woo_new_product_tab'));
	}

	/**
	 * Actions to be performed on init
	 * Check PHP session & start a new one if none exists
	 */
	function init_actions()
	{
		if (!session_id()) {
			session_start();
		}

		// Set manufacturer ID
		$this->manuId = isset($_COOKIE['manufacturerId']) ? intval($_COOKIE['manufacturerId']) : false;
		// Set model ID
		$this->modelId = isset($_COOKIE['modelId']) ? intval($_COOKIE['modelId']) : false;
		// Set type ID
		$this->typeId = isset($_COOKIE['vehicleId']) ? intval($_COOKIE['vehicleId']) : false;
		// Store Woo permalink structure
        if (function_exists('wc_get_permalink_structure')) {
	        $this->permalink_structure = wc_get_permalink_structure();
        }

		// remove_action( 'woocommerce_before_single_product_summary', 'woocommerce_show_product_images', 20 );
//		add_action('woocommerce_before_single_product_summary', array($this, 'woocommerce_show_product_images'), 20);
		// Remove "Related products" on single product page
		remove_action('woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20);
		// Alter post link
		add_filter('post_type_link', array($this, 'post_type_link_filter'), 10, 3);
	}

	/**
	 * Alter product link
	 * @param  string  $url       Product url
	 * @param  array  $post       Post object
	 * @param  boolean $leavename [description]
	 * @return string             New url
	 */
	function post_type_link_filter( $url, $post, $leavename=false )
	{
		if ('product' != get_post_type( $post ) || !$this->typeId || !is_array($this->permalink_structure)) {
			return $url;
		}

		$url = str_replace($this->permalink_structure["product_rewrite_slug"], $this->typeId . '/' . $this->permalink_structure["product_rewrite_slug"], $url);
		return $url;
	}

	/**
	 * Override search results label
	 * @param  array $this_crumbs Existing breadcrumbs
	 * @param  array $instance    Instance
	 * @return array              New breadcrumbs
	 */
	function filter_woocommerce_get_breadcrumb($this_crumbs, $instance)
	{
		if (!is_array($_GET) || !array_key_exists('s', $_GET)) {
			return $this_crumbs;
		}

		$value = $_GET["s"];
		$position = count($this_crumbs) - 1;
		$this_crumbs[$position][0] = sprintf(__('Search results for &ldquo;%s&rdquo;', 'woocommerce'), $value);
		return $this_crumbs;
	}

	/**
	 * Override WooCommerce setting for hiding empty categories
	 * @return bool         Show or hide empty categories - true/hide, false/show
	 */
	function hide_empty_categories($hide_empty)
	{
		$hide_empty = false;
		return $hide_empty;
	}

	/**
	 * Check if current category is a subcategory
	 * @param  int  $cat_id Category id, defaults to null
	 * @return boolean      true - category is a subcategory,
	 *                      false - category is a root category
	 */
	function is_subcategory($cat_id = null)
	{
		if (is_tax('product_cat')) {
			if (empty($cat_id)) {
				$cat_id = get_queried_object_id();
			}

			$cat = get_term($cat_id, 'product_cat');
			if (empty($cat->parent)) {
				return false;
			} else {
				return true;
			}
		}

		return false;
	}

	/**
	 * Hide product count on category list
	 * NOTE: function needs to be empty
	 */
	function hide_category_count()
	{
	}

	/**
	 * Write main differences between Tecdoc and Woo categories to file
	 */
	function write_global_diff_to_file(&$woo_tecdoc_diff, $_cat_file, $txt)
	{
		foreach ($woo_tecdoc_diff as $cat) {
			$txt .= $cat."\n";
		}

		fwrite($_cat_file, $txt);
		fclose($_cat_file);
	}

	/**
	 * Add TecDoc tab to single product
	 * @param  array $tabs Existing product tabs
	 * @return array       New tab list
	 */
	function woo_new_product_tab($tabs)
	{
        if (ep_tecdoc_article(get_the_ID())) {
	        // Adds the new tab
	        $tabs['tecdoc_info'] = [
		        'title'    => __('TecDoc Information', 'ep-tecdoc'),
		        'priority' => 50,
		        'callback' => [ $this, 'tecdoc_tab_content' ]
	        ];

	        $tabs['tecdoc_oenumbers'] = [
                'title' => __('Article Numbers', 'ep-tecdoc'),
                'priority' => 50,
                'callback' => [$this, 'tecdoc_tab_oenumbers'],
            ];

	        $tabs['tecdoc_vehicles'] = [
                'title' => __('Linked Vehicles', 'ep-tecdoc'),
                'priority' => 50,
                'callback' => [$this, 'tecdoc_tab_vehicles'],
            ];
        }

		return $tabs;
	}

	static function translateFittingPosition($string)
    {
        $translations = [
            'left' => __('Left', 'ep-tecdoc'),
            'right' => __('Right', 'ep-tecdoc'),
            'front' => __('Front', 'ep-tecdoc'),
            'front axle' => __('Front Axle', 'ep-tecdoc'),
	        'front axle left' => __('Front Axle Left', 'ep-tecdoc'),
            'front axle right' => __('Front Axle Right', 'ep-tecdoc'),
            'front axle left and right' => __('Front Axle Left and Right', 'ep-tecdoc'),
            'lower front axle' => __('Lower Front Axle', 'ep-tecdoc'),
            'upper front axle' => __('Upper Front Axle', 'ep-tecdoc'),
            'rear' => __('Rear', 'ep-tecdoc'),
            'rear axle' => __('Rear Axle', 'ep-tecdoc'),
            'rear axle left' => __('Rear Axle Left', 'ep-tecdoc'),
            'rear axle right' => __('Rear Axle Right', 'ep-tecdoc'),
            'rear axle left and right' => __('Rear Axle Left and Right', 'ep-tecdoc'),
            'lower rear axle' => __('Lower Rear Axle', 'ep-tecdoc'),
            'upper rear axle' => __('Upper Rear Axle', 'ep-tecdoc'),
        ];

        return $translations[strtolower($string)] ?? $string;
    }

    /**
     * Add content to newly added TecDoc tab
     */
	function tecdoc_tab_content()
	{
        $article = ep_tecdoc_article(get_the_ID());

        echo '<p>'. __('Brand', 'ep-tecdoc') .': <strong>'. $article['brand']['name'] .'</strong></p>';

        foreach ($article['attributes'] as $attribute) {
            if (100 === $attribute['id']) {
                $attribute['value'] = self::translateFittingPosition($attribute['value']);
            }

	        echo '<p>'. __($attribute['name'], 'ep-tecdoc') .': <strong>'. $attribute['value'] .'</strong></p>';
        }

        foreach ($article['infos'] as $info) {
	        echo '<p>'. __($info['name'], 'ep-tecdoc') .': <strong>'. $info['text'] .'</strong></p>';
        }
	}

	function tecdoc_tab_oenumbers()
    {
	    $article = ep_tecdoc_article(get_the_ID());
	    $oenumbers = [];

	    foreach ($article['oenumbers'] as $number) {
		    $oenumbers[$number['brand']][] = $number['number'];
	    }

	    if (count($oenumbers) > 0): ?>
            <h3 class="accordion_title"><?= __('Article Numbers', 'ep-tecdoc'); ?></h3>

            <div class="accordion" rel="0">
			    <?php foreach ($oenumbers as $brand => $numbers): ?>
                    <div class="accordion-item">
                        <a href="#" class="accordion-title plain">
                            <button class="toggle"><i class="icon-angle-down"></i></button>
                            <span><?= $brand; ?></span>
                        </a>

                        <div class="accordion-inner">
                            <ul>
							    <?php foreach ($numbers as $number): ?>
                                    <li>
                                        <a href="<?= esc_attr(home_url(sprintf('?s=%s&post_type=product', $number))); ?>">
                                            <?= $number; ?>
                                        </a>
                                    </li>
							    <?php endforeach; ?>
                            </ul>
                        </div>
                    </div>
			    <?php endforeach; ?>
            </div>
		    <?php
	    endif;
    }

	function tecdoc_tab_vehicles()
    {
        $tecdoc = ep_tecdoc_service();
        $article = ep_tecdoc_article(get_the_ID());

        $vehicles = $tecdoc->getVehicleStringsLinkedToArticle($article['id']);

        if (count($vehicles) > 0): ?>
            <h3 class="accordion_title"><?= __('Linked Vehicles', 'ep-tecdoc'); ?></h3>

            <div class="accordion" rel="1">
                <?php foreach ($vehicles as $brand => $_vehicles): ?>
                    <div class="accordion-item">
                        <a href="#" class="accordion-title plain">
                            <button class="toggle"><i class="icon-angle-down"></i></button>
                            <span><?= $brand; ?></span>
                        </a>

                        <div class="accordion-inner">
                            <ul>
                                <?php foreach ($_vehicles as $vehicle): ?>
                                    <li><?= $vehicle; ?></li>
                                <?php endforeach; ?>
                            </ul>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
        <?php endif;
    }
}
