<?php
/**
 * Plugin Name: EP TecDoc
 * Description: TecDoc integracija.
 * Version: 1.0.2
 * Author: Elektronika Perhoč
 * Author URI: https://ep.hr
 */

use Ep\TecDoc\AjaxHandler;

define('EP_TECDOC_PLUGIN', __FILE__);
define('EP_TECDOC_DIR', __DIR__);
define('EP_TECDOC_URL', rtrim(plugin_dir_url(EP_TECDOC_PLUGIN), '/'));

require_once __DIR__ . '/includes/product.php';
require_once __DIR__ . '/includes/rewrite.php';
require_once __DIR__ . '/includes/search.php';

require_once __DIR__ . '/includes/class-term-custom-fields.php';
new Tecdoc_Term_Custom_Fields();
require_once __DIR__ . '/includes/class-woocommerce-overrides.php';
new wooCommerceOverrides();

add_action('plugins_loaded', function() {
    load_plugin_textdomain('ep-tecdoc', false, basename(__DIR__) . '/languages');
});

/**
 * Inicijalizacija.
 */
add_action('init', function() {
	// Proizvodi
	add_action('pre_get_posts', 'ep_tecdoc_product_cat_query', 10);
	add_action('the_posts', 'ep_tecdoc_product_get_posts', 10, 2);
	// Slike proizvoda
//	add_filter('get_post_metadata', 'ep_tecdoc_product_metadata', 10, 3);
//	add_filter('wp_get_attachment_image_src', 'ep_tecdoc_image_src', 10, 2);

	require_once __DIR__ . '/includes/class-shortcode.php';
	new tecdocWooShortcode();

	$services = ep_services();

	if ($services->has('TecDocProductProvider')) {
		$services->get('TecDocProductProvider');
	}
});

add_filter('ep/config/providers', function(array $providers) {
	$providers[] = \Ep\TecDoc\ConfigProvider::class;
	return $providers;
});

/**
 * Registracija ajax handlera samo za ajax requestove.
 */
add_action('admin_init', function() {
	if (defined('DOING_AJAX')) {
		new AjaxHandler(ep_tecdoc_service());
	}
});

add_action('wp_enqueue_scripts', function() {
	if ($support = get_theme_support('tecdoc')) {
		$handle = is_array($support) && isset($support[0]['js-handle']) ? $support[0]['js-handle'] : 'jquery';
	} else {
		$handle = 'ep-tecdoc';
		wp_enqueue_style('ep-tecdoc', EP_TECDOC_URL . '/dist/ep-tecdoc.min.css');
		wp_enqueue_script('ep-tecdoc', EP_TECDOC_URL . '/dist/ep-tecdoc.min.js', ['jquery']);
	}

	wp_localize_script($handle, 'tecdoc_settings_object', [
		'ajax_url' => admin_url('admin-ajax.php'),
		'siteurl' => WP_HOME,
		'strings' => [
			'featuredManufacturers' => __('Featured Manufacturers', 'ep-tecdoc'),
			'allManufacturers' => __('All Manufacturers', 'ep-tecdoc'),
			'model' => _x('Model', 'Model vozila', 'ep-tecdoc'),
			'year' => __('Year', 'ep-tecdoc'),
            'type' => _x('Type', 'Tip vozila', 'ep-tecdoc'),
            'motorType' => __('Motor Type', 'ep-tecdoc'),
            'power' => __('Power', 'ep-tecdoc'),
		],

	]);
}, 9999999999);

add_action('widgets_init', function() {
	require_once __DIR__ . '/includes/class-widget.php';
	register_widget(tecdocWooWidget::class);
});

/**
 * Vraća TecDoc artikl za proizvod.
 *
 * @param $productId
 *
 * @return array
 */
function ep_tecdoc_article($productId)
{
	if ($productId > \Ep\Gath\GathService::PRODUCT_ID_OFFSET) {
		$productId -= \Ep\Gath\GathService::PRODUCT_ID_OFFSET;
	}

	$services = ep_services();
	/** @var \Psr\Cache\CacheItemPoolInterface $cache */
	$cache = $services->get('cache.tecdoc');

	$cacheKey = sprintf('articles.product.%d', $productId);
	$item = $cache->getItem($cacheKey);

	if (!$item->isHit()) {
		/** @var WP_Post[] $posts */
		global $posts;

		if (is_array($posts)) {
			foreach ($posts as $post) {
				if ($post->ID === $productId && property_exists($post, 'tecdocArticle')) {
					return $post->tecdocArticle;
				}
			}
		}

		$articleKey = get_post_meta($productId, '_tecDoc_key', true);
		if (!$articleKey) return null;

		$tecdoc = ep_tecdoc_service();
		$articleId = $tecdoc->getArticleId($articleKey);
		if (!$articleId) return null;

		$articles = $tecdoc->getArticlesByIds([$articleId]);

		if (count($articles) > 0) {
			$article = $articles[0];
			$fullArticles = $tecdoc->getArticlesByGenericIds([$article['genericArticleId']]);

			if (count($fullArticles) > 0) {
				foreach ($fullArticles as $fullArticle) {
					if ($fullArticle['id'] === $article['id']) {
						$article = $fullArticle;
						break;
					}
				}
			}

			$item->set($article);
			$cache->save($item);
		}
	}

	return $item->get();
}

function ep_tecdoc_service()
{
	$services = ep_services();
	return $services->get('TecDoc');
}