<?php
namespace Ep\TecDoc;

use Zend\View\Renderer\RendererInterface;

class AjaxHandler
{
	/** @var TecDocService */
    protected $service;
    /** @var RendererInterface */
    protected $view;

	/**
	 * AjaxHandler constructor.
	 *
	 * @param TecDocService $service
	 */
	public function __construct(TecDocService $service)
	{
		$this->service = $service;
		$this->bindAjax();
	}

	/**
	 * @return mixed|RendererInterface
	 */
	protected function getView()
	{
		if (null === $this->view) {
			$services = ep_services();
			$this->view = $services->get('ViewRenderer');
		}

		return $this->view;
	}

    /**
     * Kači se na WordPress.
     */
	public function bindAjax()
    {
	    add_action('wp_ajax_tecdoc_get_manufacturers', [$this, 'ajaxManufacturers' ]);
	    add_action('wp_ajax_nopriv_tecdoc_get_manufacturers', [$this, 'ajaxManufacturers' ]);
        add_action('wp_ajax_tecdoc_get_models', [$this, 'ajaxModels' ]);
        add_action('wp_ajax_nopriv_tecdoc_get_models', [$this, 'ajaxModels' ]);
        add_action('wp_ajax_tecdoc_get_vehicles', [$this, 'ajaxVehicles' ]);
        add_action('wp_ajax_nopriv_tecdoc_get_vehicles', [$this, 'ajaxVehicles' ]);
        add_action('wp_ajax_tecdoc_vehicle', [$this, 'ajaxVehicle']);
        add_action('wp_ajax_nopriv_tecdoc_vehicle', [$this, 'ajaxVehicle']);
    }

    /**
     * Šalje popis proizvođača.
     */
    public function ajaxManufacturers()
    {
	    $manufacturers = $this->service->getManufacturers();

	    foreach ($manufacturers as &$manufacturer) {
	    	$manufacturer['group'] = 'rest';
	    }

	    $featured = $this->service->getFeaturedManufacturers();

	    foreach ($featured as &$manufacturer) {
	    	$manufacturer['id'] .= 'f';
		    $manufacturer['group'] = 'featured';
	    }

	    wp_send_json(array_merge($featured, $manufacturers));
    }

    /**
     * Šalje popis modela.
     */
    public function ajaxModels()
    {
    	$models = [];

    	if (isset($_POST['manufacturerId'])) {
    		$models = $this->service->getModels($_POST['manufacturerId']);

    		foreach ($models as &$model) {
    			$model['group'] = 'default';
		    }
	    }

	    wp_send_json($models);
    }

    /**
     * Šalje popis vozila.
     */
    public function ajaxVehicles()
    {
    	$vehicles = [];

    	if (isset($_POST['manufacturerId'], $_POST['modelId'])) {
		    $vehicles = $this->service->getVehicles($_POST['manufacturerId'], $_POST['modelId']);
	    }

	    wp_send_json($vehicles);
    }

	/**
	 * Šalje html za trenutno odabrano vozilo.
	 */
    public function ajaxVehicle()
    {
	    $vehicle = $this->service->getSelectedVehicle();

	    if (!$vehicle) {
	    	echo '0';
	    	exit;
	    }

	    $manufacturer = $this->service->getManufacturer($vehicle['manufacturerId']);
	    $model = $this->service->getModelById($manufacturer['id'], $vehicle['modelId']);

	    echo $this->getView()->render('tecdoc/widget/vehicle.twig', [
	    	'manufacturer' => $manufacturer,
		    'model' => $model,
		    'vehicle' => $vehicle,
	    ]);
	    exit;
    }
}