<?php
namespace Ep\TecDoc;

use Ep\Core\AbstractFactory;
use Ep\WordPress\Settings\SettingsProviderInterface;
use Zend\Stdlib\ArrayUtils;

/**
 * Class ConfigProvider
 *
 * @package Ep\TecDoc
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class ConfigProvider implements SettingsProviderInterface
{
	public function __invoke()
	{
		$settings = $this->getDefaults()['ep_tecdoc'];

		if (function_exists('get_option')) {
			$settings = ArrayUtils::merge($settings, get_option('ep_tecdoc', []));
		}

		if (is_string($settings['featuredManufacturerIds'])) {
			$settings['featuredManufacturerIds'] = array_map('absint', explode(';', $settings['featuredManufacturerIds']));
		}

		if (is_string($settings['excludedManufacturerIds'])) {
			$settings['excludedManufacturerIds'] = array_map('absint', explode(';', $settings['excludedManufacturerIds']));
		}

		return [
			'dependencies' => $this->getDependencies(),
			'forms' => [
				'settings-tecdoc' => include __DIR__ . '/../config/tecdoc.form.php',
			],
			'wordpress' => [
				'metadata_providers' => [
					'TecDocProductProvider',
				],
			],

			'caches' => [
				'cache.tecdoc' => [
					'adapter' => defined('WP_DEBUG') && WP_DEBUG ? 'null' : 'filesystem',
				],
			],

			'http_clients' => [
				'http.tecdoc' => [
					'cache' => 'cache.tecdoc',
					'cache_ttl' => 3600,
					'base_uri' => TecDocService::SERVICE_URI,
					'headers' => [
						'Content-Type' => 'application/json',
					],
				],
			],

			'tecdoc' => $settings,

			'twig' => [
				'paths' => [
					EP_TECDOC_DIR . '/view',
				],
			],
		];
	}

	public function getDependencies()
	{
		return [
			'aliases' => [
				'TecDoc' => TecDocService::class,
				'TecDocProductProvider' => ProductProvider::class,
			],
			'factories' => [
				TecDocService::class => TecDocServiceFactory::class,
                ProductProvider::class => AbstractFactory::class,
			],
		];
	}

	/**
	 * Vraća zadane postavke koje provider pruža.
	 *
	 * @return array
	 */
	public function getDefaults()
	{
		return [
			'ep_tecdoc' => [
				'country' => 'HR',
				'language' => 'en',
				'provider' => 10,
				'linkingTargetType' => 'P',
				'featuredManufacturerIds' => '',
				'excludedManufacturerIds' => '',
				'showOnlyFeaturedManufacturers' => '0',
				'brandIds' => '',
			],
		];
	}

	/**
	 * Vraća forme za postavke.
	 *
	 * @return array
	 */
	public function getForms()
	{
		return [
			'ep_tecdoc' => 'settings-tecdoc',
		];
	}

	/**
	 * Vraća tabove u control panelu koje ovaj provider definira.
	 *
	 * @return array
	 */
	public function getTabs()
	{
		return [[
			'id' => 'tecdoc',
			'title' => 'TecDoc',
			'optionKeys' => [
				'ep_tecdoc',
			],
		]];
	}
}