<?php
namespace Ep\TecDoc;

use Ep\Gath\WordPress\ProductMetadataProvider;
use Zend\Stdlib\ArrayUtils;

/**
 * Class ProductProvider
 *
 * @package Ep\TecDoc
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class ProductProvider extends ProductMetadataProvider
{
	/** @var TecDocService */
	protected $tecdoc;
	/** @var array */
	protected $tecdocArticles = [];

	protected $metaKeys = [
		'_product_image_gallery',
		'_tecdoc',
		'_thumbnail_id',
	];

	/** @var array */
	protected $thumbnails = [];

	/** @noinspection PhpMissingParentConstructorInspection
	 * @param TecDocService $tecdoc
	 */
	public function __construct(TecDocService $tecdoc)
	{
		$this->tecdoc = $tecdoc;

		add_action('wp', function() {
			$this->load();
		});
	}

	/**
	 * Vraća vrijednost metapodatka iz nekog drugog izvora, ovisno o implementaciji.
	 *
	 * @param int $postId
	 * @param string $metaKey
	 *
	 * @param mixed|null $metaValue
	 *
	 * @return mixed
	 */
	public function getMetadata(int $postId, string $metaKey, $metaValue = null)
	{
		if (!isset($this->tecdocArticles[$postId])) {
			if ($articleKey = get_post_meta($postId, '_tecDoc_key', true)) {
				if ($articleId = $this->tecdoc->getArticleId($articleKey)) {
					$articles = $this->tecdoc->getArticlesByIds([$articleId]);

					if (count($articles) > 0) {
						$this->tecdocArticles[$postId] = $articles[0];
					}
				}
			}
		}

		if (isset($this->tecdocArticles[$postId])) {
			$article = $this->tecdocArticles[$postId];

			switch ($metaKey) {
				case '_product_image_gallery':
					get_post_meta($postId, '_thumbnail_id');
					$gallery = !empty($metaValue) ? array_filter(explode(',', $metaValue)) : [];

					if (isset($article['images']) && count($article['images']) > 0) {
						if (isset($this->thumbnails[$postId])) {
							array_unshift($gallery, $this->thumbnails[$postId]);
						}
					}

					if (isset($article['images']) && count($article['images']) > 1) {
						$articleImages = $article['images'];
						array_shift($articleImages);

						$gallery = ArrayUtils::merge($articleImages, $gallery);
					}

					return implode(',', $gallery);
				case '_tecdoc':
					return $article;
				case '_thumbnail_id':
					if (isset($article['images']) && count($article['images']) > 0) {
						if (!empty($metaValue)) {
							$this->thumbnails[$postId] = $metaValue;
						}

						return sprintf('tecdoc-%s', $article['images'][0]);
					}

					break;
			}
		}

		return $metaValue;
	}

	/**
	 * Učitava metapodatke za proizvode u $this->load.
	 */
	protected function loadMetadata()
	{

	}
}